@@ -1,6 +1,8 @@
+//! Functions using all supported type patterns.
+
 use crate::types::{
-    ambiguous1, ambiguous2, some_foreign_type, CallbackFFISlice, Callbacku8u8, Context, Empty, EnumDocumented, FFIError, Generic, Opaque, Phantom, SomeForeignType,
-    StructDocumented, UseAsciiStringPattern, Vec3f32,
+    ambiguous1, ambiguous2, common, some_foreign_type, CallbackFFISlice, Callbacku8u8, Context, Empty, EnumDocumented, FFIError, Generic, Opaque, Phantom,
+    SomeForeignType, StructDocumented, UseAsciiStringPattern, Vec3f32,
 };
 use interoptopus::ffi_function;
 use interoptopus::patterns::ascii_pointer::AsciiPointer;
@@ -13,6 +15,7 @@ pub extern "C" fn primitive_void() {}
 
 #[ffi_function]
 #[no_mangle]
+#[allow(clippy::unused_unit)]
 pub extern "C" fn primitive_void2() -> () {}
 
 #[ffi_function]
@@ -170,7 +173,7 @@ pub extern "C" fn pattern_ffi_slice(ffi_slice: FFISlice<u32>) -> u32 {
     ffi_slice.as_slice().unwrap_or(&[]).len() as u32
 }
 
-#[ffi_function(debug)]
+#[ffi_function]
 #[no_mangle]
 pub extern "C" fn pattern_ffi_slice_delegate(callback: CallbackFFISlice) -> u8 {
     callback.call(FFISlice::from_slice(&[1, 2, 3]))
@@ -183,7 +186,7 @@ pub extern "C" fn pattern_class_method(context: Option<&mut Context>) -> u32 {
         None => 0,
         Some(c) => {
             dbg!(c.some_field);
-            c.some_field = 2 * c.some_field;
+            c.some_field *= 2;
             c.some_field
         }
     }
@@ -201,6 +204,9 @@ pub extern "C" fn pattern_class_method_success_enum_fail(_context: Option<&mut C
     FFIError::Fail
 }
 
+/// # Safety
+///
+/// This function may only be called with a context returned by a succeeding `pattern_class_create`.
 #[ffi_function]
 #[no_mangle]
 #[allow(unused_unsafe)]
@@ -231,3 +237,9 @@ pub extern "C" fn ambiguous_2(x: ambiguous2::Vec) -> ambiguous2::Vec {
 pub extern "C" fn ambiguous_3(x: ambiguous1::Vec, y: ambiguous2::Vec) -> bool {
     (x.x as f64 - y.x).abs() < 0.5
 }
+
+#[ffi_function]
+#[no_mangle]
+pub extern "C" fn namespaced_type(x: common::Vec) -> common::Vec {
+    x
+}
