@@ -1,7 +1,10 @@
+//! All supported type patterns.
+
 use interoptopus::ffi_type;
-use interoptopus::lang::c::{CType, CompositeType, Field, Function, PrimitiveType};
-use interoptopus::lang::rust::{CTypeInfo, CallbackXY, FunctionInfo};
+use interoptopus::lang::c::{CType, CompositeType, Field, PrimitiveType};
+use interoptopus::lang::rust::CTypeInfo;
 use interoptopus::patterns::ascii_pointer::AsciiPointer;
+use interoptopus::patterns::callbacks::CallbackXY;
 use interoptopus::patterns::slice::FFISlice;
 use interoptopus::patterns::success_enum::Success;
 use std::marker::PhantomData;
@@ -14,8 +17,7 @@ pub struct SomeForeignType {
 
 // Surrogate we can use instead of `SomeForeignType`
 pub fn some_foreign_type() -> CType {
-    let mut composite = CompositeType::new("SomeForeignType".to_string());
-    composite.add_field(Field::new("x".to_string(), CType::Primitive(PrimitiveType::U32)));
+    let composite = CompositeType::new("SomeForeignType".to_string(), vec![Field::new("x".to_string(), CType::Primitive(PrimitiveType::U32))]);
     CType::Composite(composite)
 }
 
@@ -151,3 +153,14 @@ pub mod ambiguous2 {
         Z = 200,
     }
 }
+
+pub mod common {
+    use interoptopus::ffi_type;
+
+    #[ffi_type(namespace = "common")]
+    #[repr(C)]
+    pub struct Vec {
+        pub x: f64,
+        pub z: f64,
+    }
+}
